// 处理主题样式
export function handleThemeStyle(theme: string) {
  document.documentElement.style.setProperty("--el-color-primary", theme);
  for (let i = 1; i <= 9; i++) {
    document.documentElement.style.setProperty(`--el-color-primary-light-${i}`, `${getLightColor(theme, i / 10)}`);
  }
  for (let i = 1; i <= 9; i++) {
    document.documentElement.style.setProperty(`--el-color-primary-dark-${i}`, `${getDarkColor(theme, i / 10)}`);
  }
}

/**
 * 处理菜单样式
 */
export const handleMenuStyle = (color: any) => {
  document.documentElement.style.setProperty("--custom-base-menu-color", color.baseMenuColor); //菜单标题未选中文本颜色
  document.documentElement.style.setProperty("--custom-base-menu-light-color", color.baseMenuLightColor); //菜单标题选中文本颜色
  document.documentElement.style.setProperty("--costom-base-menu-color-active", color.baseMenuColorActive); // 菜单主文本下级被选中
  document.documentElement.style.setProperty("--costom-base-menu-light-background", color.baseMenuLightBackground); // 菜单选中之后背景颜色
  document.documentElement.style.setProperty("--costom-base-menu-background", color.baseMenuBackground); //主菜单背景颜色
  document.documentElement.style.setProperty("--costom-base-sub-menu-background", color.baseSubMenuBackground); //子菜单背景颜色
  document.documentElement.style.setProperty("--costom--base-sub-menu-hover", color.BaseSubMenuHover); //鼠标滑过背景颜色
  document.documentElement.style.setProperty("--costom-base-menu-box-shadow", color.BaseMenuBoxShodow); //菜单边框阴影颜色
};

export const handleFontStyle = (e: string) => {
  document.documentElement.style.setProperty("--costom-base-font", e); //菜单标题未选中文本颜色
};

// hex颜色转rgb颜色
export function hexToRgb(str: string) {
  str = str.replace("#", "");
  let hexs: any = str.match(/../g);
  for (let i = 0; i < 3; i++) {
    hexs![i] = parseInt(hexs[i], 16);
  }
  return hexs;
}

// rgb颜色转Hex颜色
export function rgbToHex(r: number, g: number, b: number) {
  let hexs = [r.toString(16), g.toString(16), b.toString(16)];
  for (let i = 0; i < 3; i++) {
    if (hexs[i].length == 1) {
      hexs[i] = `0${hexs[i]}`;
    }
  }
  return `#${hexs.join("")}`;
}

// 变浅颜色值
export function getLightColor(color: string, level: number) {
  let rgb = hexToRgb(color);
  for (let i = 0; i < 3; i++) {
    rgb[i] = Math.floor((255 - rgb[i]) * level + rgb[i]);
  }
  return rgbToHex(rgb[0], rgb[1], rgb[2]);
}

// 变深颜色值
export function getDarkColor(color: string, level: number) {
  let rgb = hexToRgb(color);
  for (let i = 0; i < 3; i++) {
    rgb[i] = Math.floor(rgb[i] * (1 - level));
  }
  return rgbToHex(rgb[0], rgb[1], rgb[2]);
}
